@@ -56,13 +56,11 @@ class __EXPORT ArrayRef : public TypeRef
 protected:
 	typedef enum {ARRAY, STACK, QUEUE, FALLBACK} arraytype_t;
 
-	class Array : public Counted
+	class Array : public Counted, public ConditionalAccess
 	{
 	protected:
 		friend class ArrayRef;
 
-		Conditional cond;
-
 		size_t head, tail;
 
 		arraytype_t type;
